# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['netapi',
 'netapi.connector',
 'netapi.connector.eos',
 'netapi.connector.linux',
 'netapi.net',
 'netapi.net.eos',
 'netapi.probe',
 'netapi.probe.eos',
 'netapi.probe.ios',
 'netapi.probe.junos',
 'netapi.probe.linux',
 'netapi.probe.nxos',
 'netapi.probe.xe',
 'netapi.probe.xr']

package_data = \
{'': ['*']}

install_requires = \
['bitmath>=1.3,<2.0',
 'netaddr>=0.7.19,<0.8.0',
 'pendulum>=2.0,<3.0',
 'pydantic>=0.26.0,<0.27.0',
 'pyeapi>=0.8.2,<0.9.0',
 'pyyaml>=5.1,<6.0']

setup_kwargs = {
    'name': 'netapi',
    'version': '0.2.0',
    'description': 'Network API library. A programmatic interface to network devices',
    'long_description': '# NetAPI\n\nNetwork API library that perform the core of the work -> requests execution and data parsing.\n\nIt relies on the main vendor libraries to perform its work and its main objective to grant network objects that can be used with your applications.\n\n## Installation\n\nYou can directly install it using pip\n\n```\npip install netapi\n```\n\n### Development Version\n\nYou will need [poetry](https://github.com/sdispater/poetry) for clonning and installing the repo\n\n## How it works\n\nIs a library that abstracts the connection and parsing method of the data collected on the target device. It then presents a developer-friendly object that you can use to interact with.\n\nAll the objects are created with some cool features for manipulating their attributes and creating your applications on top of it. An example is the `IPNetwork` object returned of the ipv4 address of an interface. You will see that later.\n\nThe library is divided in 3 main types of objects:\n\n- **Device**: These are connector objects used fot the `net` and `probes` objects. Needed for the execution and data collection.\n- **Net**: These are network _entities_, which basically means technologies or parts of the network protocols like interface, vlan, vrrp, bgp, etc...\n- **Probes**: These are tester objects to run in your `device` objects. For example `ping` or `trace`.\n\nThere is also a `Metadata` object that collects information about the implementation, how many times the object has been executed and timestamp. Useful for reports and other tests.\n\n### Network Entities example\n\nHere is an example of how to use the library when using a network entity. In this case `Interface`:\n\n```python\n# Use Arista pyeapi client for connection\nfrom netapi.connector.pyeapier import Device\nfrom netapi.net.pyeapier import Interface\n\nfrom pprint import pprint\n\n# Create a device connection object using its api https interface\nrouter01 = Device(\n    host="192.168.0.77",\n    username="someuser",\n    password="somepassword",\n    transport="https"\n)\n```\n\nShow device connection attributes, notice that secrets are hidden\n```python\nprint(router01)\n\nDevice(host=\'192.168.0.77\', username=\'someuser\', port=None, net_os=\'eos\', transport=\'https\')\n```\n\nYou can see the metadata for this instance and get information like timestamp, type of implementation, id of the instance, among other things:\n```python\nprint(router01.metadata)\n\nMetadata(name=\'device\', type=\'entity\', implementation=\'EOS-PYEAPI\', created_at=DateTime(2019, 5, 14, 16, 47, 35, 319134), id=UUID(\'51d317ab-584d-4f32-a789-402770c361f2\'), updated_at=None, collection_count=0, parent=None)\n```\n\nYou can run a command/action and retrieve its output. The format would depend mostly of the device, net_os, implementation (like EOS-PYEAPI or raw SSH for example) and the type of command.\n```python\npprint(router01.run(\'show version\'))\n\n{\'show version\': {\'architecture\': \'i386\',\n                  \'bootupTimestamp\': 1557851831.0,\n                  \'hardwareRevision\': \'\',\n                  \'internalBuildId\': \'1a44ce37-92c4-48b6-b922-38b7eed939b6\',\n                  \'internalVersion\': \'4.21.5F-11604264.4215F\',\n                  \'isIntlVersion\': False,\n                  \'memFree\': 1372616,\n                  \'memTotal\': 2015608,\n                  \'mfgName\': \'\',\n                  \'modelName\': \'vEOS\',\n                  \'serialNumber\': \'\',\n                  \'systemMacAddress\': \'0c:59:30:85:d7:1d\',\n                  \'uptime\': 1158.4,\n                  \'version\': \'4.21.5F\'}}\n```\nThis library provides common handlers,  for well known network technologies. Here is an example for the Management 1 interface. Notice that I pass the device connector object:\n```python\nmgmt1 = Interface(name="Management1", connector=router01)\n\n# You can collect its attributes by running the get() method\nmgmt1.get()\n```\n\nYou can see its attributes. Since it is an interface I will only show some key ones\n```python\nprint(mgmt1)\n\nInterface(name=\'Management1\',\n          description=\'Some description\',\n          enabled=True,\n          instance=\'MANAGEMENT\',\n          members=None,\n          status_up=True,\n          status=\'connected\',\n          last_status_change=DateTime(2019, 5, 9, 11, 40, 38, 144796, tzinfo=Timezone(\'Europe/Dublin\')),\n          number_status_changes=4,\n          last_clear=DateTime(2019, 5, 9, 11, 34, 32, 150340, tzinfo=Timezone(\'Europe/Dublin\')),\n          update_interval=5.0,\n          forwarding_model=\'routed\',\n          physical=InterfacePhysical(mtu=Byte(1500.0),\n                                     bandwidth=Bit(1000000000.0),\n                                     duplex=\'duplexFull\',\n                                     mac=EUI(\'28-99-3A-F8-5D-E7\')),\n          optical=InterfaceOptical(tx=-2.5,\n                                   rx=-5.4,\n                                   status="green",\n                                   serial_number="XXXYYYZZZ",\n                                   media_type="10GBASE-SR"),\n          addresses=InterfaceIP(ipv4=IPNetwork(\'10.193.0.177/24\'),\n                                ipv6=None,\n                                secondary_ipv4=[],\n                                dhcp=None))\n```\n\nNOTE: The `counters` attribute is not refelcted by default. You can access it directly with `<interface_obj>.counters`\n\nThere are multiple parameters here but and I ommitted othere but you can see that IP addresses are netaddr IPNetwork object and similarly the MAC addresses are EUI objects. Also the counter_refresh interval are datetime objects.\n\nThese instances also have metadata\n```python\nprint(mgmt1.metadata)\n\nMetadata(name=\'interface\', type=\'entity\', implementation=\'EOS-PYEAPI\', created_at=DateTime(2019, 5, 14, 16, 43, 44, 819105), id=UUID(\'73297adf-a0d6-4f8d-b247-0d793e577efb\'), updated_at=DateTime(2019, 5, 14, 16, 43, 54, 483277), collection_count=1, parent=None)\n```\n\nYou can see that in the metadata the updated_at field is populated? This happened because we invoked the get() method to collect the data. Now let\'s change the interface description and refresh the interface data (this is done outside of the script)\n\nAssuming a change to the description was done, now retrieve again the data\n```python\nprint(mgmt01.description)\n\nDUMMY DESCRIPTION\n```\n\nYou can see that the description changes but also the metadata has been updated!\n```python\nprint(mgmt01.metadata)\n\nMetadata(name=\'interface\', type=\'entity\', implementation=\'EOS-PYEAPI\', created_at=DateTime(2019, 5, 14, 16, 43, 44, 819105), id=UUID(\'73297adf-a0d6-4f8d-b247-0d793e577efb\'), updated_at=DateTime(2019, 5, 14, 17, 20, 27, 557810), collection_count=2, parent=None)\n```\nYou can see updated_at has been updated :) and the collection_count has increased to 2\n\n### Network Probes example\n\nThis is a simple example running a Ping against an specific IP address and applying a custom analysis to the result.\n\nFirst initiate the device object and specify a target\n```python\nfrom netapi.connector.linux.subprocesser import Device\nfrom netapi.probe.linux.subprocesser import Ping\n\nhost = Device()\nping = Ping(target="1.1.1.1", connector=host)\n```\n\nYou can see the `Ping` object with the following attributes:\n```python\nprint(ping)\n\nPing(target=\'1.1.1.1\', resolve_target=True, target_ip=IPAddress(\'1.1.1.1\'), target_name=\'one.one.one.one\', source=None, instance=None, count=5, timeout=2, size=692, df_bit=False, interval=1.0, ttl=None, result={})\n```\nYou can see that `result` attribute is empty, we need to tell to execute the `Ping` and we can apply our own logic to it.\n\nThe ping object is to be executed on my machine, you can see the `command` to be used:\n```python\nprint(ping.command())\n\n\'ping 1.1.1.1 size 692 repeat 5 timeout 2 interval 1.0\'\n```\n\nIf we execute it as es we can get a result like\n```python\nping.execute()\n\nPing(target=\'1.1.1.1\', resolve_target=True, target_ip=IPAddress(\'1.1.1.1\'), target_name=\'one.one.one.one\', source=None, instance=None, count=5, timeout=2, size=692, df_bit=False, interval=1.0, ttl=None, result={\'probes_sent\': 5, \'probes_received\': 5, \'packet_loss\': 0.0, \'rtt_min\': 2.035, \'rtt_avg\': 2.073, \'rtt_max\': 2.125, \'flag\': \'green\', \'alert\': False, \'status_code\': 0, \'status_up\': True})\n```\n\nWe can use our own threshold in execution to manipulate the `flag` and `status_up` parameters.\n\n```python\nping.execute(critical_threshold=-1)\n\nIn [17]: ping.result\nOut[17]:\n{\'probes_sent\': 5,\n \'probes_received\': 5,\n \'packet_loss\': 0.0,\n \'rtt_min\': 1.929,\n \'rtt_avg\': 2.209,\n \'rtt_max\': 2.97,\n \'flag\': \'red\',\n \'alert\': True,\n \'status_code\': 2,\n \'status_up\': False}\n```\nYou can see that is `status_up = False` even though all the probes were received successfully. Usefull for custom testing.\n',
    'author': 'David Flores',
    'author_email': 'davidflores7_8@hotmail.com',
    'url': 'https://gitlab.com/the-networkers/netaudithor/netapi',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
